.. _introduction_tutorial:

=========================
Introduction tutorial
=========================


:ref:`Quickstart: 5 minutes to zfit <5-minutes-to-zfit>`


A more extensive introduction: 20 minutes to zfit.

.. toctree::
    :maxdepth: 1
    :hidden:

    ../getting_started/5_minutes_to_zfit
    components_introduction

.. toctree::
    :maxdepth: 1

    ../_tmp/zfit-tutorials/introduction/Introduction.ipynb


:ref:`Getting started with the individual components of zfit <components_introduction>`
